@@ -219,15 +219,15 @@ ZEND_API void * __zend_realloc(void *p, size_t len) ZEND_ATTRIBUTE_ALLOC_SIZE(2)
 #define perealloc2_recoverable_rel(ptr, size, copy_size, persistent) ((persistent)?realloc((ptr), (size)):erealloc2_recoverable_rel((ptr), (size), (copy_size)))
 #define pestrdup_rel(s, persistent) ((persistent)?strdup(s):estrdup_rel(s))
 
-ZEND_API int zend_set_memory_limit(size_t memory_limit);
+ZEND_API void zend_set_memory_limit(size_t memory_limit);
 
 ZEND_API void start_memory_manager(void);
-ZEND_API void shutdown_memory_manager(int silent, int full_shutdown);
-ZEND_API int is_zend_mm(void);
-ZEND_API int is_zend_ptr(const void *ptr);
+ZEND_API void shutdown_memory_manager(bool silent, bool full_shutdown);
+ZEND_API bool is_zend_mm(void);
+ZEND_API bool is_zend_ptr(const void *ptr);
 
-ZEND_API size_t zend_memory_usage(int real_usage);
-ZEND_API size_t zend_memory_peak_usage(int real_usage);
+ZEND_API size_t zend_memory_usage(bool real_usage);
+ZEND_API size_t zend_memory_peak_usage(bool real_usage);
 
 /* fast cache for HashTables */
 #define ALLOC_HASHTABLE(ht)	\
@@ -246,7 +246,7 @@ ZEND_API size_t zend_memory_peak_usage(int real_usage);
 typedef struct _zend_mm_heap zend_mm_heap;
 
 ZEND_API zend_mm_heap *zend_mm_startup(void);
-ZEND_API void zend_mm_shutdown(zend_mm_heap *heap, int full_shutdown, int silent);
+ZEND_API void zend_mm_shutdown(zend_mm_heap *heap, bool full_shutdown, bool silent);
 ZEND_API void*  ZEND_FASTCALL _zend_mm_alloc(zend_mm_heap *heap, size_t size ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC) ZEND_ATTRIBUTE_MALLOC;
 ZEND_API void   ZEND_FASTCALL _zend_mm_free(zend_mm_heap *heap, void *p ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC);
 ZEND_API void*  ZEND_FASTCALL _zend_mm_realloc(zend_mm_heap *heap, void *p, size_t size ZEND_FILE_LINE_DC ZEND_FILE_LINE_ORIG_DC);
@@ -274,7 +274,7 @@ ZEND_API size_t zend_mm_gc(zend_mm_heap *heap);
 #define ZEND_MM_CUSTOM_HEAP_STD   1
 #define ZEND_MM_CUSTOM_HEAP_DEBUG 2
 
-ZEND_API int zend_mm_is_custom_heap(zend_mm_heap *new_heap);
+ZEND_API bool zend_mm_is_custom_heap(zend_mm_heap *new_heap);
 ZEND_API void zend_mm_set_custom_handlers(zend_mm_heap *heap,
                                           void* (*_malloc)(size_t),
                                           void  (*_free)(void*),
@@ -295,8 +295,8 @@ typedef struct _zend_mm_storage zend_mm_storage;
 
 typedef	void* (*zend_mm_chunk_alloc_t)(zend_mm_storage *storage, size_t size, size_t alignment);
 typedef void  (*zend_mm_chunk_free_t)(zend_mm_storage *storage, void *chunk, size_t size);
-typedef int   (*zend_mm_chunk_truncate_t)(zend_mm_storage *storage, void *chunk, size_t old_size, size_t new_size);
-typedef int   (*zend_mm_chunk_extend_t)(zend_mm_storage *storage, void *chunk, size_t old_size, size_t new_size);
+typedef bool   (*zend_mm_chunk_truncate_t)(zend_mm_storage *storage, void *chunk, size_t old_size, size_t new_size);
+typedef bool   (*zend_mm_chunk_extend_t)(zend_mm_storage *storage, void *chunk, size_t old_size, size_t new_size);
 
 typedef struct _zend_mm_handlers {
 	zend_mm_chunk_alloc_t       chunk_alloc;
