@@ -1,6 +1,4 @@
 /*
-   +----------------------------------------------------------------------+
-   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
    | Copyright (c) The PHP Group                                          |
    +----------------------------------------------------------------------+
@@ -24,7 +22,7 @@
 #include <dmalloc.h>
 #endif
 
-#define PHP_API_VERSION 20190902
+#define PHP_API_VERSION 20200930
 #define PHP_HAVE_STREAMS
 #define YYDEBUG 0
 #define PHP_DEFAULT_CHARSET "UTF-8"
@@ -128,7 +126,7 @@ typedef int pid_t;
 #endif
 #include <assert.h>
 
-#if HAVE_UNIX_H
+#ifdef HAVE_UNIX_H
 #include <unix.h>
 #endif
 
@@ -297,11 +295,10 @@ END_EXTERN_C()
 #define php_ignore_value(x) ZEND_IGNORE_VALUE(x)
 
 /* global variables */
-#if !defined(PHP_WIN32)
-#define PHP_SLEEP_NON_VOID
+#ifndef PHP_WIN32
 #define php_sleep sleep
 extern char **environ;
-#endif	/* !defined(PHP_WIN32) */
+#endif	/* ifndef PHP_WIN32 */
 
 #ifdef PHP_PWRITE_64
 ssize_t pwrite(int, void *, size_t, off64_t);
@@ -314,8 +311,10 @@ ssize_t pread(int, void *, size_t, off64_t);
 BEGIN_EXTERN_C()
 void phperror(char *error);
 PHPAPI size_t php_write(void *buf, size_t size);
-PHPAPI size_t php_printf(const char *format, ...) PHP_ATTRIBUTE_FORMAT(printf, 1,
-		2);
+PHPAPI size_t php_printf(const char *format, ...) PHP_ATTRIBUTE_FORMAT(printf, 1, 2);
+PHPAPI size_t php_printf_unchecked(const char *format, ...);
+PHPAPI int php_during_module_startup(void);
+PHPAPI int php_during_module_shutdown(void);
 PHPAPI int php_get_module_initialized(void);
 #ifdef HAVE_SYSLOG_H
 #include "php_syslog.h"
@@ -323,7 +322,7 @@ PHPAPI int php_get_module_initialized(void);
 #else
 #define php_log_err(msg) php_log_err_with_severity(msg, 5)
 #endif
-PHPAPI ZEND_COLD void php_log_err_with_severity(char *log_message, int syslog_type_int);
+PHPAPI ZEND_COLD void php_log_err_with_severity(const char *log_message, int syslog_type_int);
 int Debug(char *format, ...) PHP_ATTRIBUTE_FORMAT(printf, 1, 2);
 int cfgparse(void);
 END_EXTERN_C()
@@ -348,7 +347,6 @@ PHPAPI ZEND_COLD void php_error_docref1(const char *docref, const char *param1,
 PHPAPI ZEND_COLD void php_error_docref2(const char *docref, const char *param1, const char *param2, int type, const char *format, ...)
 	PHP_ATTRIBUTE_FORMAT(printf, 5, 6);
 #ifdef PHP_WIN32
-PHPAPI ZEND_COLD void php_win32_docref1_from_error(DWORD error, const char *param1);
 PHPAPI ZEND_COLD void php_win32_docref2_from_error(DWORD error, const char *param1, const char *param2);
 #endif
 END_EXTERN_C()
@@ -366,7 +364,6 @@ END_EXTERN_C()
 BEGIN_EXTERN_C()
 PHPAPI extern int (*php_register_internal_extensions_func)(void);
 PHPAPI int php_register_internal_extensions(void);
-PHPAPI int php_mergesort(void *base, size_t nmemb, size_t size, int (*cmp)(const void *, const void *));
 PHPAPI void php_register_pre_request_shutdown(void (*func)(void *), void *userdata);
 PHPAPI void php_com_initialize(void);
 PHPAPI char *php_get_current_user(void);
